PVCam Camera - Heros Devices 0.7.1 documentation

Skip to content
Back to top
View this page

# PVCam Camera

From: Teledyne Technologies

Class: `herosdevices.hardware.teledyne.pvcam.PvcamCamera`

Driver Quality Index: beta

Requires the following packages

pyvcam

A class to interface with Teledyne PVCam Cameras.

The class provides functionality to control and capture images from cameras. It manages camera configuration, acquisition, and data streaming compatible with the atomiq camera template.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.teledyne.pvcam.PvcamCamera` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
cam_id | <class ‘str’> |  | Serial number of the cam. Can be obtained for example from the ids-peak GUI. Note, that the id is only the first part of the value shown in the GUI, the part including the device type is not unique and may not be added to `cam_id`.
config_dict | <class ‘dict’> |  | Dict of configuration values like shown in the json example above.
default_config | str | None | None | Default key in `config_dict` to use.
lib_path | str | None | None | Path to vendor library.

The following JSON strings can be used to start a HERO device representation of `PvcamCamera` using BOSS.

    {
        "_id": "my_PvcamCamera",
        "classname": "herosdevices.hardware.teledyne.pvcam.PvcamCamera",
        "arguments": {
            "cam_id": "<class 'str'>",
            "config_dict": "<class 'dict'>",
            "default_config": null,
            "lib_path": null
        }
    }

generated from signature